@@ -5,16 +5,22 @@ from dataclasses import dataclass
 import json
 import dacite
 
+
 @dataclass
 class WorkflowResponse:
-    outputs: List[str]
-    namedOutputs: List[Any]
-    executionTrace: Dict[Any, Any]
+    outputs: Optional[List[str]]
+    namedOutputs: Optional[List[Any]]
+    executionTrace: Optional[Dict[Any, Any]]
 
     @classmethod
     def create(cls, response: Dict[Any, Any]):
         result = dacite.from_dict(data_class=cls, data=response)
-        result.namedOutputs = dict(*(((k,v) for k,v in x.items()) for x in result.namedOutputs))
+        try:
+            result.namedOutputs = dict(
+                *(((k, v) for k, v in x.items()) for x in result.namedOutputs)
+            )
+        except Exception as e:
+            result.namedOutputs = []
         return result
 
     def __getitem__(self, key):
@@ -23,18 +29,23 @@ class WorkflowResponse:
     def generations(self):
         result = []
         for block, block_info in self.executionTrace.items():
-            if block_info["node_type"] == "AGIBLOCK": #lol
-                result.append(dict(id=block, inputs=block_info["inputs"], output=block_info["output"]))
+            if block_info["node_type"] == "AGIBLOCK":  # lol
+                result.append(
+                    dict(id=block, inputs=block_info["inputs"], output=block_info["output"])
+                )
         return result
 
     def print_generations(self):
         def _fmt_block(block):
             return json.dumps(block, indent=2)
+
         for block in self.generations():
             print(_fmt_block(block))
 
 
-def run_workflow(workflow_id: str, api_key: str, args: List[str], kwargs: Dict[str, Any]) -> WorkflowResponse:
+def run_workflow(
+    workflow_id: str, api_key: str, args: List[str], kwargs: Dict[str, Any]
+) -> WorkflowResponse:
     assert api_key is not None, "api_key not provided"
     headers = {
         "accept": "application/json",
@@ -43,7 +54,6 @@ def run_workflow(workflow_id: str, api_key: str, args: List[str], kwargs: Dict[s
         "apiKey": api_key,
         "args": args,
         "kwargs": kwargs,
-        
     }
     response = requests.post(
         f"https://prometheus-api.llm.llc/api/workflow/{workflow_id}",
@@ -52,10 +62,11 @@ def run_workflow(workflow_id: str, api_key: str, args: List[str], kwargs: Dict[s
     )
     decoded_response = response.content.decode("utf-8")
     response_dict = json.loads(decoded_response)
-    workflow_response = WorkflowResponse(outputs=response_dict["outputs"], namedOutputs=response_dict.get("namedOutputs", None), executionTrace=response_dict.get("executionTrace", None))
-        
+    workflow_response = dacite.from_dict(data_class=WorkflowResponse, data=response_dict)
+
     return workflow_response
 
+
 def get_type_signature(workflow_id: str, api_key: str):
     url = f"https://prometheus-api.llm.llc/api/workflow/{workflow_id}?apiKey={api_key}"
     headers = {"accept": "application/json"}
